# PeTeR_69
A small demo library that describes the input number through PeTeR.

### Installation
```
pip install peter-69
```

### Get started
How to describe your number with this library:

```Python
from peter_69 import PeTeR

# Instantiate a PeTeR object
peter = PeTeR()

# Call the says method
result = peter.says(-42069)
```